﻿using System.Text;
using System.Collections.Generic;

namespace Delivery.AlipayClass
{
    /// <summary>
    /// 类名：alipay_service
    /// 功能：支付宝外部服务接口控制
    /// 详细：该页面是请求参数核心处理文件，不需要修改
    /// 版本：3.1
    /// 修改日期：2010-09-29
    /// 说明：
    /// 以下代码只是为了方便商户测试而提供的样例代码，商户可以根据自己网站的需要，按照技术文档编写,并非一定要使用该代码。
    /// 该代码仅供学习和研究支付宝接口使用，只是提供一个参考
    /// </summary>
    public class AlipayService
    {
		private string gateway = string.Empty;                //网关地址
		private string _key = string.Empty;                    //交易安全校验码
		private string _input_charset = string.Empty;         //编码格式
		private string _sign_type = string.Empty;              //加密方式（签名方式）
		private string mysign = string.Empty;                 //加密结果（签名结果）
        private Dictionary<string, string> sPara = new Dictionary<string, string>();//需要加密的已经过滤后的参数数组

        /// <summary>
        /// 构造函数
        /// 从配置文件及入口文件中初始化变量
        /// </summary>
        /// <param name="partner">合作身份者ID</param>
        /// <param name="trade_no">支付宝交易号。它是登陆支付宝网站在交易管理中查询得到，一般以8位日期开头的纯数字（如：20100419XXXXXXXXXX） </param>
        /// <param name="logistics_name">物流公司名称</param>
        /// <param name="invoice_no">物流发货单号</param>
        /// <param name="transport_type">物流发货时的运输类型，三个值可选：POST（平邮）、EXPRESS（快递）、EMS（EMS）</param>
        /// <param name="seller_ip">卖家本地电脑IP地址</param>
        /// <param name="key">安全检验码</param>
        /// <param name="input_charset">字符编码格式 目前支持 gb2312 或 utf-8</param>
        /// <param name="sign_type">加密方式 不需修改</param>
        public AlipayService(string partner,
            string trade_no,
            string logistics_name,
            string invoice_no,
            string transport_type,
            string seller_ip,
            string key,
            string input_charset,
            string sign_type)
        {
            gateway = "https://www.alipay.com/cooperate/gateway.do?";
            _key = key.Trim();
            _input_charset = input_charset.ToLower();
            _sign_type = sign_type.ToUpper();
            SortedDictionary<string, string> sParaTemp = new SortedDictionary<string, string>();

            //构造加密参数数组
            sParaTemp.Add("service", "send_goods_confirm_by_platform");
            sParaTemp.Add("partner", partner);
            sParaTemp.Add("trade_no", trade_no);
            sParaTemp.Add("logistics_name", logistics_name);
            sParaTemp.Add("invoice_no", invoice_no);
            sParaTemp.Add("transport_type", transport_type);
            sParaTemp.Add("seller_ip", seller_ip);
            sParaTemp.Add("_input_charset", _input_charset);

            sPara = AlipayFunction.Para_filter(sParaTemp);
            //获得签名结果
            mysign = AlipayFunction.Build_mysign(sPara, _key, _sign_type, _input_charset);
        }

        /// <summary>
        /// 构造请求URL（GET方式请求）
        /// </summary>
        /// <returns>请求url</returns>
        public string Create_url()
        {
            string strUrl = gateway;
            string arg = AlipayFunction.Create_linkstring_urlencode(sPara);	//把数组所有元素，按照“参数=参数值”的模式用“&”字符拼接成字符串
            strUrl = strUrl + arg + "sign=" + mysign + "&sign_type=" + _sign_type;
            return strUrl;
        }

        /// <summary>
        /// 构造Post表单提交HTML（POST方式请求）
        /// </summary>
        /// <returns>输出 表单提交HTML文本</returns>
        public string Build_postform()
        {
            StringBuilder sbHtml = new StringBuilder();
            sbHtml.Append("<form id=\"alipaysubmit\" name=\"alipaysubmit\" action=\"" + gateway + "_input_charset=" + _input_charset + "\" method=\"post\">");

            foreach (KeyValuePair<string, string> temp in sPara)
            {
                sbHtml.Append("<input type=\"hidden\" name=\"" + temp.Key + "\" value=\"" + temp.Value + "\"/>");
            }

            sbHtml.Append("<input type=\"hidden\" name=\"sign\" value=\"" + mysign + "\"/>");
            sbHtml.Append("<input type=\"hidden\" name=\"sign_type\" value=\"" + _sign_type + "\"/></form>");

            sbHtml.Append("<input type=\"button\" name=\"v_action\" value=\"支付宝发货\" onClick=\"document.forms['alipaysubmit'].submit();\">");

            return sbHtml.ToString();
        }
    }
}