﻿
namespace Service
{
	using Data.Entity;
    using System.Linq;
	using System.Collections.Generic;

	public interface IAddressService
	{
        int CreateNewAddress(Data.Entity.Address theNewAddress);
        int DeleteAddress(int id);
        int UpdateAddress(Data.Entity.Address theAddress);
		IList<Data.Entity.Address> GetTheUserAddresses(System.Guid userID);
	}

	public interface ICategoryService
	{
        int CreateNewCategory(Data.Entity.Category theNewCategory);
        int DeleteCategory(int id);
		IList<Data.Entity.Category> GetCategoryByLanguage(int languageID);
        int UpdateCategory(Data.Entity.Category theCategory);
		IList<Data.Entity.Category> GetSubCategories(int parentCategoryID);
		//IList<Data.Entity.Category> GetAllCategoryByLanguage(int languageID);
		Data.Entity.Category GetCategoryByID(int id);
	}

	public interface ICountryService
	{
        int CreateNewCountry(Data.Entity.Country theNewCountry);
        IList<Data.Entity.Country> GetAllCountry();
		//Data.Entity.Country GetTheCountry(int id);
	}

	public interface IDocumentService
	{
        int CreateNewDocument(Data.Entity.Document theNewDocument);
        int DeleteDocument(int id);
        int DeleteProductDocumentMapping(int documentID);
        IList<Data.Entity.Document> GetDocumentByProduct(int productID);
    }

	public interface ILanguageService
	{
        int CreateNewLanguage(Data.Entity.Language theNewLanguage);
        IList<Data.Entity.Language> GetAllLanguage();
        int UpdateLanguage(Data.Entity.Language theLanguage);
		int DeleteLanguage(int id);
	}

	public interface ILocalStringResourceService
	{
        int CreateNewLocaleStringResource(Data.Entity.LocalStringResource theNewLocaleStringResource);
        IList<Data.Entity.LocalStringResource> GetLocaleStringResourceByLanguage(int languageID);
        int UpdateLocaleStringResource(Data.Entity.LocalStringResource theLocaleStringResource);
		IList<Data.Entity.LocalStringResource> GetAllLocaleStringResource();
		int DeleteLocaleStringResource(int id);
		Data.Entity.LocalStringResource GetTheLocalStringResource(int id);
	}

	public interface IPictureService
	{
        int CreateNewPicture(Data.Entity.Picture theNewPicture);
        IList<Data.Entity.Picture> GetPicturesByProduct(int productID);
        int UpdatePicture(Data.Entity.Picture thePicture);
        Data.Entity.Picture GetPicture(int id);
		IList<Data.Entity.Picture> GetPicturesByProduct_WithoutBinary(int productid);
		Data.Entity.Picture GetTheProductDefaultPicture(int theProductID);
	}

	public interface IProductService
	{
		int CreateNewProduct(Data.Entity.Product theNewProduct);
		int DeleteProduct(int id);
		IList<Data.Entity.Product> GetProductsByCategory(int categoryID);
		IList<Data.Entity.Product> GetProductsByTag(int tagID);
		Data.Entity.Product GetProduct(int productID);
		int UpdateProduct(Data.Entity.Product theProduct);
		IList<Data.Entity.Category> GetTheProductCategories(int productID);
		IList<Data.Entity.Product> GetProductByFilter(string metaKeywords, string noMetaKeywords, int categoryID, decimal startPrice, decimal endPrice, int languageID);
		IList<Data.Entity.Product> GetProductsByLanguage(int languageID);
		IList<Data.Entity.Product> GetAllProductsByLanguage(int languageID);
		IList<Data.Entity.ProductTag> GetTheProductTags(int theProductID);
		void SaveProduct_Category_Mapping(Data.Entity.Product_Category_Mapping theProduct_Category_Mapping);
		void SaveProductTag_Product_Mapping(Data.Entity.ProductTag_Product_Mapping theProductTag_Product_Mapping);
		IList<Data.Entity.Product_Category_Mapping> GetProduct_Category_MappingsByProduct(int theProductID);
		bool DeleteProduct_Category_Mapping(Data.Entity.Product_Category_Mapping theProduct_Category_Mapping);
		IList<Data.Entity.ProductTag_Product_Mapping> GetProductTag_Product_MappingByProduct(int theProductID);
		bool DeleteProductTag_Product_Mapping(Data.Entity.ProductTag_Product_Mapping theProductTag_Product_Mapping);
		int IsExistingTheProductAndTagMapping(int productID, int tagID);
		IList<Data.Entity.Product> GetTopSellingProducts();
		IList<Data.Entity.Product> GetProductsByCategory(int categoryID, int pageIndex, int pageSize, out int totalRecords);
		IList<Data.Entity.Product> GetProductsByLanguage(int languageID, int pageIndex, int pageSize, out int totalRecords);
		IList<Data.Entity.Product> GetProductsByTag(int tagID, int pageIndex, int pageSize, out int totalRecords);
	}

	public interface IProductAdditionalPropertyService
	{
        int CreateNewProductAdditionalProperty(Data.Entity.ProductAdditionalProperty theNewProductAdditionalProperty);
        IList<Data.Entity.ProductAdditionalProperty> GetProductAdditionalProperties(int productID);
        int UpdateProductAdditionalProperty(Data.Entity.ProductAdditionalProperty theProductAdditionalProperty);
		bool DeleteProductAdditionalProperty(int id);
		void SaveTheCustomerMustKnownContent(Data.Entity.ProductAdditionalProperty theCustomerMustKnownContent);
		Data.Entity.ProductAdditionalProperty GetTheProductAdditionalPropertyByName(string propertyName);
	}

	public interface IProductPictureService
	{
        int CreateNewProductPicture(Data.Entity.ProductPicture theNewProductPicture);
		int DeleteProductPicture(Data.Entity.ProductPicture theProductPicture);
		IList<Data.Entity.ProductPicture> GetProductPictureByProduct(int productID);
		int UpdateProductPicture(Data.Entity.ProductPicture theProductPicture);
	}

	public interface IProductRatingService
	{
        int CreateNewProductRating(Data.Entity.ProductRating theNewProductRating);
        IList<Data.Entity.ProductRating> GetProductRatingByProduct(int productID);
    }

	public interface IProductReviewService
	{
        int CreateNewProductReview(Data.Entity.ProductReview theNewProductReview);
        int DeleteProductReview(int id);
        IList<Data.Entity.ProductReview> GetProductReviewsByProduct(int productID);
        int UpdateProductReview(Data.Entity.ProductReview theProductReview);
		IList<Data.Entity.ProductReview> GetAllProductReviewsByLanguage(int languageID);
	}

	public interface IProductReviewHelpfulnessService
	{
		int CreateNewProductReviewHelpfulness(ProductReviewHelpfulness theNewProductReviewHelpfulness);
	}

	public interface IProductTagService
	{
        int CreateNewProductTag(Data.Entity.ProductTag theNewProductTag);
        int DeleteProductTag(int id);
		IList<Data.Entity.ProductTag> GetProductTagByLanguage(int languageID);
		Data.Entity.ProductTag GetTheProductTag(int id);
		int PlusOrMinus1ProductCount(int theProductTagID, int pn1);
	}

	public interface IRelatedProductService
	{
        int CreateNewRelatedProduct(Data.Entity.RelatedProduct theNewRelatedProduct);
        int DeleteRelatedProduct(int productID1, int productID2);
        IList<Data.Entity.RelatedProduct> GetRelatedProducts(int productID);
        int UpdateRelatedProduct(Data.Entity.RelatedProduct theRelatedProduct);
		IList<Data.Entity.Product> GetRelatedProducts(System.Collections.Generic.IEnumerable<int> prodIDs);
	}

	public interface ISearchLogService
	{
		int CreateNewSearchLog(SearchLog theNewSearchLog);
	}

	public interface IStateProvinceService
	{
        int CreateNewStateProvince(Data.Entity.StateProvince theNewStateProvince);
        IList<Data.Entity.StateProvince> GetStateProvinceByCountry(int countryID);
        IList<Data.Entity.City> GetCityByStateProvince(int stateProvinceID);
		IList<Data.Entity.StateProvince> GetAllStateProvince();
		IList<Data.Entity.City> GetAllCity();
	}

	public interface IUserExtensionService
	{
        int CreateNewUserExtension(Data.Entity.UserExtension theNewUserExtension);
        int UpdateUserExtension(Data.Entity.UserExtension theUserExtension);
        Data.Entity.UserExtension GetUserExtensionByUserID(System.Guid userID);
    }

	public interface IUserSessionService
	{
		int CreateNewUserSession(UserSession theNewUserSession);
	}

    public interface IShoppingCartItemService
    {
        int CreateNewShoppingCartItem(Data.Entity.ShoppingCartItem theNewShoppingCartItem);
        int DeleteShoppingCartItem(int id);
        IList<Data.Entity.ShoppingCartItem> GetShoppingCartItemByUser(System.Guid userID);
        IList<Data.Entity.ShoppingCartType> GetAllShoppingCartType();
        int UpdateShoppingCartItem(Data.Entity.ShoppingCartItem theShoppingCartItem);
		Data.Entity.ShoppingCartItem GetTheShoppingCartItem(int id);
	}

    public interface IExpressService
    {
        IList<Data.Entity.Express> GetAllExpress();
    }

    public interface IOrderService
    {
        int CreateNewOrder(Data.Entity.Order theNewOrder);
        int CreateNewOrderNote(Data.Entity.OrderNote theNewOrderNote);
        IList<Data.Entity.OrderNote> GetOrderNoteByOrder(int orderID);
        int DeleteOrder(int id);
        IList<Data.Entity.Order> GetOrderByUser(System.Guid userID);
        IList<Data.Entity.OrderStatus> GetAllOrderStatus();
        int UpdateOrder(Data.Entity.Order theOrder);
		int DeleteTheOrdersProduct(int orderID, int productID);
		IList<Data.Entity.Product> GetTheOrdersProducts(int orderID);
		int CreateNewOrderProductMapping(Data.Entity.Order_Product_Mapping theNewOrder_Product_Mapping);
		Data.Entity.Order GetTheOrderByOrderID(int orderID);
		IList<Data.Entity.Order_Product_Mapping> GetOrderProductMappingByOrder(int theOrderID);
		IList<Data.Entity.Order> GetOrdersByLanguage(int languageID);
		Data.Entity.Order GetTheOrderByOrderNumber(string orderNumber);
		Data.Entity.OrderStatus GetTheOrderStatusByStatusName(string statusName);
	}

    public interface IPaymentMethodService
    {
        int CreateNewPaymentMethod(Data.Entity.PaymentMethod theNewPaymentMethod);
        IList<Data.Entity.PaymentMethod> GetAllPaymentMethod();
        IList<Data.Entity.PaymentStatus> GetAllPaymentStatus();
		int DeletePaymentMethod(int id);
		Data.Entity.PaymentMethod GetThePaymentMethod(int id);
		int UpdatePaymentMethod(Data.Entity.PaymentMethod thePaymentMethod);
	}

    public interface IShippingMethodService
    {
        int CreateNewShippingMethod(Data.Entity.ShippingMethod theNewShippingMethod);
        IList<Data.Entity.ShippingMethod> GetAllShippingMethod();
        IList<Data.Entity.ShippingStatus> GetAllShippingStatus();
		bool DeleteShippingMethod(int id);
		int UpdateShippingMethod(Data.Entity.ShippingMethod theShippingMethod);
		IList<Data.Entity.ShippingByStateAndProvince> GetShippingByStateAndProvinceByProvince(int stateProvinceID);
		IList<Data.Entity.ShippingMethod> GetShippingMethodByProduct(int productID);
		void SaveProduct_ShippingMethod_Mapping(int productID, int shippingMethodID);
		void DeleteTheProduct_ShippingMethod_Mapping(int productID, int shippingMethodID);
	}

	public interface INewsService
	{
		int CreateNews(Data.Entity.News theNewNews);
		IList<Data.Entity.News> GetNewsByLanguage(int languageID);
		int DeleteNews(int newsID);
		IList<Data.Entity.News> GetAllNewsByLanguage(int languageID);
		Data.Entity.News GetTheNews(int id);
		int UpdateNews(Data.Entity.News theNews);
	}

	public interface ICashTicketService
	{
		int CreateNewCashTicket(Data.Entity.CashTicket theNewCashTicket);
		IList<Data.Entity.CashTicket> GetMyCashTicket(System.Guid userID);
		int UpdateCashTicket(Data.Entity.CashTicket theCashTicket);
	}
}
